summaryrefslogtreecommitdiffstats
path: root/noatun/modules/kjofol-skin/kjequalizer.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'noatun/modules/kjofol-skin/kjequalizer.cpp')
-rw-r--r--noatun/modules/kjofol-skin/kjequalizer.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/noatun/modules/kjofol-skin/kjequalizer.cpp b/noatun/modules/kjofol-skin/kjequalizer.cpp
index 51d50e97..4b260f6f 100644
--- a/noatun/modules/kjofol-skin/kjequalizer.cpp
+++ b/noatun/modules/kjofol-skin/kjequalizer.cpp
@@ -34,7 +34,7 @@ KJEqualizer::KJEqualizer(const TQStringList &l, KJLoader *p)
// needed to only blit onto screen ONCE and not for every band
TQPixmap tmp = p->pixmap(p->item("backgroundimage")[1]);
mBack = new KPixmap ( TQSize(xs,ys) );
- bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, Qt::CopyROP );
+ bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, TQt::CopyROP );
// buffer for view
mView = new TQPixmap ( xs, ys );
@@ -76,19 +76,19 @@ void KJEqualizer::paint(TQPainter *p, const TQRect &)
{
TQPixmap temp(rect().width(), rect().height());
// draw background into buffer
- bitBlt ( &temp, 0, 0, mBack, 0, 0, -1, -1, Qt::CopyROP );
+ bitBlt ( &temp, 0, 0, mBack, 0, 0, -1, -1, TQt::CopyROP );
// draw band sliders into buffer
- bitBlt( &temp, 0, 0, mView, 0, 0, rect().width(), rect().height(), Qt::CopyROP);
+ bitBlt( &temp, 0, 0, mView, 0, 0, rect().width(), rect().height(), TQt::CopyROP);
// and draw it on screen
- bitBlt(p->device(), rect().topLeft(), &temp, TQRect(0,0,-1,-1), Qt::CopyROP);
+ bitBlt(p->device(), rect().topLeft(), &temp, TQRect(0,0,-1,-1), TQt::CopyROP);
}
void KJEqualizer::slotUpdateBuffer()
{
// kdDebug(66666) << "[KJEqualizer] slotUpdateBuffer() called." << endl;
- TQBitmap regionMask( rect().width(), rect().height(), true); // fully transparent mask
- TQPainter mask( &regionMask );
+ TQBitmap regionMask( rect().width(), rect().height(), true); // fully transparent tqmask
+ TQPainter tqmask( &regionMask );
TQPoint destX = TQPoint(0, 0);
@@ -102,15 +102,15 @@ void KJEqualizer::slotUpdateBuffer()
// kdDebug(66666) << "[KJEqualizer] band=" << band << ", level=" << level << ", picNum=" << picNum << " @ xpos=" << xPos << "." << endl;
- bitBlt(mView, destX, &mBars, TQRect(xPos,0,mBandWidth,rect().height()), Qt::CopyROP);
- // make slider opaque in mask so you see something on screen
- mask.fillRect ( destX.x(), 0, mBandWidth, rect().height(), Qt::color1 );
+ bitBlt(mView, destX, &mBars, TQRect(xPos,0,mBandWidth,rect().height()), TQt::CopyROP);
+ // make slider opaque in tqmask so you see something on screen
+ tqmask.fillRect ( destX.x(), 0, mBandWidth, rect().height(), TQt::color1 );
destX += TQPoint(mXSpace,0);
} // for()
// whole thingy has been drawn, now set the mask
mView->setMask( regionMask );
- repaint();
+ tqrepaint();
}
void KJEqualizer::mouseMove(const TQPoint &p, bool in)
@@ -102,15 +102,15 @@ void KJEqualizer::slotUpdateBuffer()
destX += TQPoint(mXSpace,0);
} // for()
- // whole thingy has been drawn, now set the mask
+ // whole thingy has been drawn, now set the tqmask
mView->setMask( regionMask );